@@ -46,7 +46,8 @@ fieldmean_and_anomaly_map <- function(config = NULL,
                                       attach = FALSE,
                                       infile_attach = "auto",
                                       dwd_logo = FALSE,
-                                      verbose = TRUE) {
+                                      verbose = TRUE,
+                                      nc = NULL) {
   # Call central argument parser
   arguments_necessary <- methods::formalArgs(parse_arguments)
   arguments <- as.list(match.call())
@@ -88,6 +89,7 @@ fieldmean_and_anomaly_map <- function(config = NULL,
   new_infile <- parsedArguments$new_infile
   dwd_logo <- parsedArguments$dwd_logo
   verbose <- parsedArguments$verbose
+  nc <- parsedArguments$nc
   
   # check_infile_monitor_climate
   # if(accumulate == FALSE)
@@ -112,7 +114,8 @@ fieldmean_and_anomaly_map <- function(config = NULL,
     end_date = end_date,
     accumulate = accumulate,
     temp_dir = temp_dir,
-    verbose = verbose
+    verbose = verbose,
+    nc = nc
   )
 
   climatology_file <- calculate_climatology(
@@ -129,7 +132,8 @@ fieldmean_and_anomaly_map <- function(config = NULL,
     lat_min = lat_min,
     lat_max = lat_max,
     accumulate = accumulate,
-    verbose = verbose
+    verbose = verbose,
+    nc = nc
   )
 
   if (is_country(country_code)) {
